# $Author: Ben Timms $
# $Date: Thu Feb 8 14:47:58 2024 +0000 $
# $Revision: 4346b37 $

# Function to pause and then exit the script
function ExitWithPause($message) {
    Write-Host $message

    if($ExecutionContext.SessionState.LanguageMode -ne "ConstrainedLanguage") {
        Write-Host "Press any key to continue ..."
        $null = $host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")
    }
    exit
}

# Assign paths to variables
$sourceFolder = "$env:APPDATA\Steinberg\Activation Manager"
$destFolder = "$env:PROGRAMDATA\Steinberg\Activation Manager"

# Check if the source folder exists
if(-Not (Test-Path $sourceFolder)) {
    ExitWithPause("Folder $sourceFolder does not exist")
}

# Test for the existence of the access file or offline.json
$accessJsonPath = Join-Path -Path $sourceFolder -ChildPath "Data\access.txt"
$offlineJsonPath = Join-Path -Path $sourceFolder -ChildPath "Data\offline.json"
if(-Not (Test-Path $accessJsonPath) -And -Not (Test-Path $offlineJsonPath)) {
    ExitWithPause("Not logged in to Steinberg ID, please log in and activate the licenses first.")
}

# If the destination folder does not exist, create it
if(-Not (Test-Path $destFolder)) {
    New-Item -ItemType Directory -Force -Path $destFolder
} else {
    # If it does exist, clear its contents
    Get-ChildItem -Path $destFolder -Recurse | Remove-Item -Force -Recurse
}

# Check if the destination folder is writable
try {
    $tempFile = New-Item "$destFolder\temp.txt" -ItemType File -Force
    Remove-Item $tempFile -Force
}
catch {
    ExitWithPause("Folder $destFolder is not writable")
}


# Copy folder contents
Copy-Item -Path $sourceFolder\* -Destination $destFolder -Recurse -Force
Write-Host "Contents of $sourceFolder copied to $destFolder"

# Read the file access.txt
$accessJsonPath = Join-Path -Path $sourceFolder -ChildPath "Data\access.txt"
if(Test-Path $accessJsonPath) {
    $jsonContent = Get-Content $accessJsonPath | ConvertFrom-Json
    $licenseeEmail = $jsonContent.userEmail

    # Write a JSON called "offline.json" to the destination folder
    $offlineJsonPath = Join-Path -Path $destFolder -ChildPath "Data\offline.json"
    $offlineJsonContent = @{
        licenseeMail = $licenseeEmail
    } | ConvertTo-Json

    Set-Content -Path $offlineJsonPath -Value $offlineJsonContent
    Write-Host "Offline json written to $offlineJsonPath"
}
elseif (Test-Path $offlineJsonPath) {
    # Copy the offline.json file to the destination folder
    Copy-Item -Path $offlineJsonPath -Destination $destFolder -Force
    Write-Host "Offline json copied to $destFolder"
}

# Delete access.json from the destination folder
$destAccessJsonPath = Join-Path -Path $destFolder -ChildPath "Data\access.txt"
if(Test-Path $destAccessJsonPath) {
    Remove-Item $destAccessJsonPath -Force
    Write-Host "Deleted $destAccessJsonPath"
}

# Pause at the end to allow the user to see the output
Write-Host "License sucessfully enabled for all users. Press any key to continue ..."
$null = $host.UI.RawUI.ReadKey("NoEcho,IncludeKeyDown")